searchData={"items":[{"type":"module","title":"RectLayout","doc":"Create and manipulate rectangular objects and groups of them\n\nUse `import RectLayout` to import everything, or import only the methods you need.","ref":"RectLayout.html"},{"type":"function","title":"RectLayout.align_bottom/1","doc":"Align each item to the bottommost item","ref":"RectLayout.html#align_bottom/1"},{"type":"function","title":"Visual - RectLayout.align_bottom/1","doc":"*--*\n    |  |\n    *--*         ->\n          *---*      *--* *---*\n          |   |      |  | |   |\n          *---*     -*--*-*---*-","ref":"RectLayout.html#align_bottom/1-visual"},{"type":"function","title":"Examples - RectLayout.align_bottom/1","doc":"iex> align_bottom([rect(2, 2), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 0, y: 3, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_bottom/1-examples"},{"type":"function","title":"RectLayout.align_bottom/2","doc":"Align each item to a given y value","ref":"RectLayout.html#align_bottom/2"},{"type":"function","title":"Visual - RectLayout.align_bottom/2","doc":"*--*\n    |  |\n    *--*         ->\n          *---*\n          |   |      *--* *---*\n          *---*      |  | |   |\n    ------------    -*--*-*---*-","ref":"RectLayout.html#align_bottom/2-visual"},{"type":"function","title":"Examples - RectLayout.align_bottom/2","doc":"iex> align_bottom([rect(2, 2), rect(3, 3, 2, 2)], 6)\n    [\n      %RectLayout.Rect{x: 0, y: 4, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 3, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_bottom/2-examples"},{"type":"function","title":"RectLayout.align_left/1","doc":"Align each item the leftmost item","ref":"RectLayout.html#align_left/1"},{"type":"function","title":"Visual - RectLayout.align_left/1","doc":"|\n    *--*              *--*\n    |  |              |  |\n    *--*              *--*\n         *---*   ->   *---*\n         |   |        |   |\n         *---*        *---*\n                      |","ref":"RectLayout.html#align_left/1-visual"},{"type":"function","title":"Examples - RectLayout.align_left/1","doc":"iex> align_left([rect(2, 2), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2},\n      %RectLayout.Rect{x: 0, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_left/1-examples"},{"type":"function","title":"RectLayout.align_left/2","doc":"Align each item to a given x value to the left","ref":"RectLayout.html#align_left/2"},{"type":"function","title":"Visual - RectLayout.align_left/2","doc":"|                    |\n    | *--*               *--*\n    | |  |               |  |\n    | *--*               *--*\n    |      *---*   ->    *---*\n    |      |   |         |   |\n    |      *---*         *---*\n    |                    |","ref":"RectLayout.html#align_left/2-visual"},{"type":"function","title":"Examples - RectLayout.align_left/2","doc":"iex> align_left([rect(2, 2), rect(3, 3, 2, 2)], -2)\n    [\n      %RectLayout.Rect{x: -2, y: 0, width: 2, height: 2},\n      %RectLayout.Rect{x: -2, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_left/2-examples"},{"type":"function","title":"RectLayout.align_right/1","doc":"Align each item to the rightmost item","ref":"RectLayout.html#align_right/1"},{"type":"function","title":"Visual - RectLayout.align_right/1","doc":"|\n    *--*              *--*\n    |  |              |  |\n    *--*        ->    *--*\n         *---*       *---*\n         |   |       |   |\n         *---*       *---*\n                         |","ref":"RectLayout.html#align_right/1-visual"},{"type":"function","title":"Examples - RectLayout.align_right/1","doc":"iex> align_right([rect(2, 2), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 3, y: 0, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_right/1-examples"},{"type":"function","title":"RectLayout.align_right/2","doc":"Align each item to a given x value to the right","ref":"RectLayout.html#align_right/2"},{"type":"function","title":"Visual - RectLayout.align_right/2","doc":"|            |\n    *--*       |         *--*\n    |  |       |         |  |\n    *--*       | ->      *--*\n         *---* |        *---*\n         |   | |        |   |\n         *---* |        *---*\n               |            |","ref":"RectLayout.html#align_right/2-visual"},{"type":"function","title":"Examples - RectLayout.align_right/2","doc":"iex> align_right([rect(2, 2), rect(3, 3, 2, 2)], 6)\n    [\n      %RectLayout.Rect{x: 4, y: 0, width: 2, height: 2},\n      %RectLayout.Rect{x: 3, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_right/2-examples"},{"type":"function","title":"RectLayout.align_top/1","doc":"Align each item to the topmost item","ref":"RectLayout.html#align_top/1"},{"type":"function","title":"Visual - RectLayout.align_top/1","doc":"*--*            -*--*-*---*-\n    |  |             |  | |   |\n    *--*         ->  *--* *---*\n          *---*\n          |   |\n          *---*","ref":"RectLayout.html#align_top/1-visual"},{"type":"function","title":"Examples - RectLayout.align_top/1","doc":"iex> align_top([rect(2, 2), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 0, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_top/1-examples"},{"type":"function","title":"RectLayout.align_top/2","doc":"Align each item to a given y value","ref":"RectLayout.html#align_top/2"},{"type":"function","title":"Visual - RectLayout.align_top/2","doc":"------------    -*--*-*---*-\n    *--*             |  | |   |\n    |  |             *--* *---*\n    *--*         ->\n          *---*\n          |   |\n          *---*","ref":"RectLayout.html#align_top/2-visual"},{"type":"function","title":"Examples - RectLayout.align_top/2","doc":"iex> align_top([rect(2, 2), rect(3, 3, 2, 2)], -2)\n    [\n      %RectLayout.Rect{x: 0, y: -2, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: -2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#align_top/2-examples"},{"type":"function","title":"RectLayout.bottom/1","doc":"Get the bottommost y of an item or a list of items","ref":"RectLayout.html#bottom/1"},{"type":"function","title":"Visual - RectLayout.bottom/1","doc":"*---*\n    |   |\n    *---*\n         *---*\n         |   |\n    -----*---*-","ref":"RectLayout.html#bottom/1-visual"},{"type":"function","title":"Examples - RectLayout.bottom/1","doc":"iex> bottom(rect(2, 2))\n  2\n  iex> bottom(rect(2, 2, 2, 2))\n  4\n  iex> bottom([rect(2, 2), rect(2, 2, 2, 2)])\n  4","ref":"RectLayout.html#bottom/1-examples"},{"type":"function","title":"RectLayout.bottom/2","doc":"Set the y so the bottommost part of the item is at y","ref":"RectLayout.html#bottom/2"},{"type":"function","title":"Examples - RectLayout.bottom/2","doc":"iex> bottom(rect(2, 2), 4)\n  %RectLayout.Rect{x: 0, y: 2, width: 2, height: 2}","ref":"RectLayout.html#bottom/2-examples"},{"type":"function","title":"RectLayout.center_x/1","doc":"Get the center x attribute of the item.","ref":"RectLayout.html#center_x/1"},{"type":"function","title":"Visual - RectLayout.center_x/1","doc":"*---*\n    -|---|-\n     *---*","ref":"RectLayout.html#center_x/1-visual"},{"type":"function","title":"Examples - RectLayout.center_x/1","doc":"iex> center_x(rect(3, 5))\n  1.5","ref":"RectLayout.html#center_x/1-examples"},{"type":"function","title":"RectLayout.center_x/2","doc":"Set the center x attribute of the item.\nPosition the item so that the new x is now its horizontal center","ref":"RectLayout.html#center_x/2"},{"type":"function","title":"Visual - RectLayout.center_x/2","doc":"*---*\n    -|---|-\n     *---*","ref":"RectLayout.html#center_x/2-visual"},{"type":"function","title":"Examples - RectLayout.center_x/2","doc":"iex> center_x(rect(3, 5), 5)\n  %RectLayout.Rect{x: 3.5, y: 0, width: 3, height: 5}","ref":"RectLayout.html#center_x/2-examples"},{"type":"function","title":"RectLayout.center_y/1","doc":"Get the center y attribute of the item.","ref":"RectLayout.html#center_y/1"},{"type":"function","title":"Visual - RectLayout.center_y/1","doc":"*-|-*\n    | | |\n    *-|-*","ref":"RectLayout.html#center_y/1-visual"},{"type":"function","title":"Examples - RectLayout.center_y/1","doc":"iex> center_y(rect(3, 5))\n  2.5","ref":"RectLayout.html#center_y/1-examples"},{"type":"function","title":"RectLayout.center_y/2","doc":"Set the center y attribute of the item.\nPosition the item so that the new y is now its vertical center","ref":"RectLayout.html#center_y/2"},{"type":"function","title":"Visual - RectLayout.center_y/2","doc":"*-|-*\n    | | |\n    *-|-*","ref":"RectLayout.html#center_y/2-visual"},{"type":"function","title":"Examples - RectLayout.center_y/2","doc":"iex> center_y(rect(3, 5), 5)\n  %RectLayout.Rect{x: 0, y: 2.5, width: 3, height: 5}","ref":"RectLayout.html#center_y/2-examples"},{"type":"function","title":"RectLayout.constrain_height/2","doc":"Set the height and modify the width to keep the aspect ratio\nFor a list, apply the new height to each item in the list","ref":"RectLayout.html#constrain_height/2"},{"type":"function","title":"Examples - RectLayout.constrain_height/2","doc":"iex> constrain_height(rect(4, 2), 4)\n    %RectLayout.Rect{x: 0, y: 0, width: 8.0, height: 4}\n\n    iex> constrain_height([rect(4, 2), rect(4, 8)], 4)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 8.0, height: 4},\n      %RectLayout.Rect{x: 0, y: 0, width: 2.0, height: 4}\n    ]","ref":"RectLayout.html#constrain_height/2-examples"},{"type":"function","title":"RectLayout.constrain_width/2","doc":"Set the width and modify the height to keep the aspect ratio\nFor a list, apply the new width to each item in the list","ref":"RectLayout.html#constrain_width/2"},{"type":"function","title":"Examples - RectLayout.constrain_width/2","doc":"iex> constrain_width(rect(2, 4), 4)\n    %RectLayout.Rect{x: 0, y: 0, width: 4, height: 8.0}\n\n    iex> constrain_width([rect(2, 4), rect(8, 4)], 4)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 4, height: 8.0},\n      %RectLayout.Rect{x: 0, y: 0, width: 4, height: 2.0}\n    ]","ref":"RectLayout.html#constrain_width/2-examples"},{"type":"function","title":"RectLayout.distribute_horizontal/2","doc":"Distribute each item in the list horizontally to cover the assigned `width` with a consistent gap between items","ref":"RectLayout.html#distribute_horizontal/2"},{"type":"function","title":"Visual - RectLayout.distribute_horizontal/2","doc":"*---*-*-*         *---*  *-----*  *-------*\n    |   | | |         |   |  |     |  |       |\n    *---* | |    ->   *---*  |     |  |       |\n    *---*-*-*                *---*-*  *---*---*\n                      <--------width---------->","ref":"RectLayout.html#distribute_horizontal/2-visual"},{"type":"function","title":"Examples - RectLayout.distribute_horizontal/2","doc":"iex> distribute_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 12)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 4.0, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 9.0, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#distribute_horizontal/2-examples"},{"type":"function","title":"RectLayout.distribute_vertical/2","doc":"Distribute each item in the list vertically to cover the assigned `height` with a consistent gap between items","ref":"RectLayout.html#distribute_vertical/2"},{"type":"function","title":"Visual - RectLayout.distribute_vertical/2","doc":"*---*      ▲\n                       |   |      |\n                       *---*      |\n                                  |\n    *---*-*-*          *-----*    |\n    |   | | |          |     |    |\n    *---* | |    ->    |     |    |\n    |     | |          |     |  height\n    *-----* |          *-----*    |\n    |       |                     |\n    *-------*          *-------*  |\n                       |       |  |\n                       |       |  |\n                       |       |  |\n                       |       |  |\n                       |       |  |\n                       *-------*  ▼","ref":"RectLayout.html#distribute_vertical/2-visual"},{"type":"function","title":"Examples - RectLayout.distribute_vertical/2","doc":"iex> distribute_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 12)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 4.0, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 9.0, width: 3, height: 3}\n    ]","ref":"RectLayout.html#distribute_vertical/2-examples"},{"type":"function","title":"RectLayout.extrude/2","doc":"Extrude the edges of a rect outward (or inward) and keeping the position","ref":"RectLayout.html#extrude/2"},{"type":"function","title":"Visual - RectLayout.extrude/2","doc":"*-------*\n    *---*      |       |\n    |   |  ->  |       |\n    *---*      |       |\n               *-------*","ref":"RectLayout.html#extrude/2-visual"},{"type":"function","title":"Examples - RectLayout.extrude/2","doc":"iex> extrude(rect(2, 2), 1)\n    %RectLayout.Rect{x: -1, y: -1, width: 4, height: 4}\n\n    iex> extrude(rect(4, 4), -1)\n    %RectLayout.Rect{x: 1, y: 1, width: 2, height: 2}","ref":"RectLayout.html#extrude/2-examples"},{"type":"function","title":"RectLayout.flow_horizontal/2","doc":"Distribute each item in the list horizontally with a set gap\n\n#","ref":"RectLayout.html#flow_horizontal/2"},{"type":"function","title":"Options - RectLayout.flow_horizontal/2","doc":"- `:x` where to start the flow from, default `0`\n- `:gap` the gap between items, default `0`","ref":"RectLayout.html#flow_horizontal/2-options"},{"type":"function","title":"Visual - RectLayout.flow_horizontal/2","doc":"*---*-*-*         *---**-----**-------*\n    |   | | |         |   ||     ||       |\n    *---* | |    ->   *---*|     ||       |\n    *---*-*-*              *-----**-------*\n                      <-------width------->","ref":"RectLayout.html#flow_horizontal/2-visual"},{"type":"function","title":"Examples - RectLayout.flow_horizontal/2","doc":"iex> flow_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 3, y: 2, width: 3, height: 3}\n    ]\n\n    iex> flow_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], gap: 2)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 3, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 7, y: 2, width: 3, height: 3}\n    ]\n\n    iex> flow_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], gap: 2, x: 2)\n    [\n      %RectLayout.Rect{x: 2, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 5, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 9, y: 2, width: 3, height: 3}\n    ]","ref":"RectLayout.html#flow_horizontal/2-examples"},{"type":"function","title":"RectLayout.flow_vertical/2","doc":"Distribute each item in the list vertically with a set gap\n\n#","ref":"RectLayout.html#flow_vertical/2"},{"type":"function","title":"Options - RectLayout.flow_vertical/2","doc":"- `:y` where to start the flow from, default `0`\n- `:gap` the gap between items, default `0`","ref":"RectLayout.html#flow_vertical/2-options"},{"type":"function","title":"Visual - RectLayout.flow_vertical/2","doc":"*---*      ▲\n                       |   |      |\n                       *---*      |\n    *---*-*-*          *-----*    |\n    |   | | |          |     |    |\n    *---* | |    ->    |     |    |\n    |     | |          |     |  height\n    *-----* |          *-----*    |\n    |       |          *-------*  |\n    *-------*          |       |  |\n                       |       |  |\n                       |       |  |\n                       |       |  |\n                       |       |  |\n                       *-------*  ▼","ref":"RectLayout.html#flow_vertical/2-visual"},{"type":"function","title":"Examples - RectLayout.flow_vertical/2","doc":"iex> flow_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)])\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 3, width: 3, height: 3}\n    ]\n\n    iex> flow_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], gap: 2)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 3, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 7, width: 3, height: 3}\n    ]\n\n    iex> flow_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], gap: 2, y: 2)\n    [\n      %RectLayout.Rect{x: 0, y: 2, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 5, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 9, width: 3, height: 3}\n    ]","ref":"RectLayout.html#flow_vertical/2-examples"},{"type":"function","title":"RectLayout.group/1","doc":"Creates an `%RectLayout.Group{}`, used to work with a group of graphical items.\nany modification of its x, y, width or height affects all of its children, proportionally.","ref":"RectLayout.html#group/1"},{"type":"function","title":"Examples - RectLayout.group/1","doc":"iex> group([rect(10,20),rect(5,5)])\n    %RectLayout.Group{\n      rect: %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20},\n      children: [\n        %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20},\n        %RectLayout.Rect{x: 0, y: 0, width: 5, height: 5}\n      ]\n    }","ref":"RectLayout.html#group/1-examples"},{"type":"function","title":"RectLayout.group_children/1","doc":"Get the children of a group","ref":"RectLayout.html#group_children/1"},{"type":"function","title":"Examples - RectLayout.group_children/1","doc":"iex> g = group([rect(10, 20), rect(5, 5)])\n    iex> group_children(g)\n    [\n      %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20},\n      %RectLayout.Rect{x: 0, y: 0, width: 5, height: 5}\n    ]","ref":"RectLayout.html#group_children/1-examples"},{"type":"function","title":"RectLayout.group_children/2","doc":"Update the children of a group\nWhen updating it will also will update the bounding rect of the group","ref":"RectLayout.html#group_children/2"},{"type":"function","title":"Examples - RectLayout.group_children/2","doc":"iex> g = group([rect(10, 20), rect(5, 5)])\n    iex> group_children(g, [rect(2, 2)])\n    %RectLayout.Group{\n      rect: %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2},\n      children: [\n        %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2}\n      ]\n    }","ref":"RectLayout.html#group_children/2-examples"},{"type":"function","title":"RectLayout.height/1","doc":"Get the height attribute of the item. Shortcut for `RectLayout.Object.height/1`","ref":"RectLayout.html#height/1"},{"type":"function","title":"RectLayout.height/2","doc":"Set the height attribute of the item. Shortcut for `RectLayout.Object.height/2`","ref":"RectLayout.html#height/2"},{"type":"function","title":"RectLayout.left/1","doc":"Get the leftmost x of a list of items","ref":"RectLayout.html#left/1"},{"type":"function","title":"Visual - RectLayout.left/1","doc":"|\n    *---*\n    |   |\n    *---*\n    |    *---*\n    |    |   |\n    |    *---*","ref":"RectLayout.html#left/1-visual"},{"type":"function","title":"Examples - RectLayout.left/1","doc":"iex> left([rect(2, 2), rect(2, 2, 2, 2)])\n  0","ref":"RectLayout.html#left/1-examples"},{"type":"function","title":"RectLayout.max_height/1","doc":"Get the maximum height of a list of items","ref":"RectLayout.html#max_height/1"},{"type":"function","title":"Examples - RectLayout.max_height/1","doc":"iex> max_height([rect(2, 1), rect(3, 5, 1, 1), rect(4, 4, 1, 1)])\n  5","ref":"RectLayout.html#max_height/1-examples"},{"type":"function","title":"RectLayout.max_width/1","doc":"Get the maximum width of a list of items","ref":"RectLayout.html#max_width/1"},{"type":"function","title":"Examples - RectLayout.max_width/1","doc":"iex> max_width([rect(2, 1), rect(3, 5, 1, 1), rect(4, 4, 1, 1)])\n  4","ref":"RectLayout.html#max_width/1-examples"},{"type":"function","title":"RectLayout.rect/4","doc":"Creates an `%RectLayout.Rect{}`, a primitive used to track info about rectangles.\nIt does not have any other attributes except its x, y, width and height","ref":"RectLayout.html#rect/4"},{"type":"function","title":"Examples - RectLayout.rect/4","doc":"iex> rect(10, 20, 2, 5)\n    %RectLayout.Rect{x: 2, y: 5, width: 10, height: 20}\n\n    iex> rect(10, 20)\n    %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20}","ref":"RectLayout.html#rect/4-examples"},{"type":"function","title":"RectLayout.right/1","doc":"Get the rightmost x of an item or a list of items","ref":"RectLayout.html#right/1"},{"type":"function","title":"Visual - RectLayout.right/1","doc":"*---*   |\n  |   |   |\n  *---*   |\n      *---*\n      |   |\n      *---*\n          |","ref":"RectLayout.html#right/1-visual"},{"type":"function","title":"Examples - RectLayout.right/1","doc":"iex> right(rect(2, 2))\n  2\n  iex> right(rect(2, 2, 2, 2))\n  4\n  iex> right([rect(2, 2), rect(2, 2, 2, 2)])\n  4","ref":"RectLayout.html#right/1-examples"},{"type":"function","title":"RectLayout.right/2","doc":"Set the x so the rightmost part of the item is at x","ref":"RectLayout.html#right/2"},{"type":"function","title":"Examples - RectLayout.right/2","doc":"iex> right(rect(2, 2), 4)\n  %RectLayout.Rect{x: 2, y: 0, width: 2, height: 2}","ref":"RectLayout.html#right/2-examples"},{"type":"function","title":"RectLayout.spread_horizontal/3","doc":"Spread out each item in the list horizontally to cover the assigned `width`\nItems are spread evenly centered on their vertical axis\nNo overlap is allowed and items push each other to the right\n\n#","ref":"RectLayout.html#spread_horizontal/3"},{"type":"function","title":"Options: - RectLayout.spread_horizontal/3","doc":"- `:x` from which x position to start the spread, default `0`\n- `:gap` the minimum gap between items, default `0`\n- `:cols` the number of columns to spread items in, you can select a bigger number than the number of items, default `length(items)`","ref":"RectLayout.html#spread_horizontal/3-options"},{"type":"function","title":"Visual - RectLayout.spread_horizontal/3","doc":"|        |        |\n    *---*-*-*         *-|-*   *--|--* *---|---*\n    |   | | |         | | |   |  |  | |   |   |\n    *---* | |    ->   *-|-*   |  |  | |   |   |\n    *---*-*-*           |     *--|--* *---|---*\n                        |        |        |\n                        |        |        |\n                    <----------width---------->","ref":"RectLayout.html#spread_horizontal/3-visual"},{"type":"function","title":"Examples - RectLayout.spread_horizontal/3","doc":"iex> spread_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 9)\n    [\n      %RectLayout.Rect{x: 1.0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 3.5, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 6.0, y: 2, width: 3, height: 3}\n    ]\n\n    iex> spread_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 6, gap: 2)\n    [\n      %RectLayout.Rect{x: 0.5, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 3.5, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 7.5, y: 2, width: 3, height: 3}\n    ]\n\n    iex> spread_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 9, x: 2)\n    [\n      %RectLayout.Rect{x: 3.0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 5.5, y: 1, width: 2, height: 2},\n      %RectLayout.Rect{x: 8.0, y: 2, width: 3, height: 3}\n    ]\n\n    iex(4)> spread_horizontal([rect(1, 1, 0, 0), rect(2, 2, 1, 1)], 9, cols: 3)\n    [\n      %RectLayout.Rect{x: 1.0, y: 0, width: 1, height: 1},\n      %RectLayout.Rect{x: 3.5, y: 1, width: 2, height: 2},\n    ]","ref":"RectLayout.html#spread_horizontal/3-examples"},{"type":"function","title":"RectLayout.spread_vertical/3","doc":"Spread out each item in the list vertically to cover the assigned `height`\nItems are spread evenly centered on their horizontal axis\nNo overlap is allowed and items push each other down\n\n#","ref":"RectLayout.html#spread_vertical/3"},{"type":"function","title":"Options: - RectLayout.spread_vertical/3","doc":"- `:y` from which y position to start the spread, default `0`\n- `:gap` the minimum gap between items, default `0`\n- `:rows` the number of rows to spread items in, you can select a bigger number than the number of items, default `length(items)`","ref":"RectLayout.html#spread_vertical/3-options"},{"type":"function","title":"Visual - RectLayout.spread_vertical/3","doc":"▲\n                                           |\n                            *---*          |\n                        ----|   |------    |\n                            *---*          |\n                                           |\n    *---*-*-*                              |\n    |   | | |               *-----*        |\n    *---* | |    ->         |     |        |\n    |     | |           ----|     |----  height\n    *-----* |               |     |        |\n    |       |               *-----*        |\n    *-------*               *-------*      |\n                            |       |      |\n                            |       |      |\n                        ----|       |--    |\n                            |       |      |\n                            |       |      |\n                            *-------*      ▼","ref":"RectLayout.html#spread_vertical/3-visual"},{"type":"function","title":"Examples - RectLayout.spread_vertical/3","doc":"iex> spread_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 9)\n    [\n      %RectLayout.Rect{x: 0, y: 1.0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 3.5, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 6.0, width: 3, height: 3}\n    ]\n\n    iex> spread_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 6, gap: 2)\n    [\n      %RectLayout.Rect{x: 0, y: 0.5, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 3.5, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 7.5, width: 3, height: 3}\n    ]\n\n    iex> spread_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1), rect(3, 3, 2, 2)], 9, y: 2)\n    [\n      %RectLayout.Rect{x: 0, y: 3.0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 5.5, width: 2, height: 2},\n      %RectLayout.Rect{x: 2, y: 8.0, width: 3, height: 3}\n    ]\n\n    iex(4)> spread_vertical([rect(1, 1, 0, 0), rect(2, 2, 1, 1)], 9, rows: 3)\n    [\n      %RectLayout.Rect{x: 0, y: 1.0, width: 1, height: 1},\n      %RectLayout.Rect{x: 1, y: 3.5, width: 2, height: 2},\n    ]","ref":"RectLayout.html#spread_vertical/3-examples"},{"type":"function","title":"RectLayout.sprite/2","doc":"Creates an `%RectLayout.Sprite{}`, which is used to track external data for a rect.","ref":"RectLayout.html#sprite/2"},{"type":"function","title":"Examples - RectLayout.sprite/2","doc":"iex> image = \"my image\"\n    \"my image\"\n    iex> sprite(rect(10, 20), image)\n    %RectLayout.Sprite{\n      rect: %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20},\n      content: \"my image\"\n    }","ref":"RectLayout.html#sprite/2-examples"},{"type":"function","title":"RectLayout.sprite_content/1","doc":"Get the content of a sprite.","ref":"RectLayout.html#sprite_content/1"},{"type":"function","title":"Examples - RectLayout.sprite_content/1","doc":"iex> s = sprite(rect(10, 20), \"one\")\n    iex> sprite_content(s)\n    \"one\"","ref":"RectLayout.html#sprite_content/1-examples"},{"type":"function","title":"RectLayout.sprite_content/2","doc":"Update the content of a sprite.","ref":"RectLayout.html#sprite_content/2"},{"type":"function","title":"Examples - RectLayout.sprite_content/2","doc":"iex> s = sprite(rect(10, 20), \"one\")\n    iex> sprite_content(s, \"two\")\n    %RectLayout.Sprite{\n      rect: %RectLayout.Rect{x: 0, y: 0, width: 10, height: 20},\n      content: \"two\"\n    }","ref":"RectLayout.html#sprite_content/2-examples"},{"type":"function","title":"RectLayout.surrounding_rect/1","doc":"Create a rectangle that surrounds all the items in the list","ref":"RectLayout.html#surrounding_rect/1"},{"type":"function","title":"Visual - RectLayout.surrounding_rect/1","doc":"*---*----*\n    |   |    |\n    *---*    |\n    |    *---*\n    |    |   |\n    *----*---*","ref":"RectLayout.html#surrounding_rect/1-visual"},{"type":"function","title":"Examples - RectLayout.surrounding_rect/1","doc":"iex> surrounding_rect([rect(2, 2), rect(2, 2, 2, 2)])\n    %RectLayout.Rect{x: 0, y: 0, width: 4, height: 4}","ref":"RectLayout.html#surrounding_rect/1-examples"},{"type":"function","title":"RectLayout.threshold_bottom/2","doc":"Push item to the top of a given line. If the line is before it, don't do anything","ref":"RectLayout.html#threshold_bottom/2"},{"type":"function","title":"Visual - RectLayout.threshold_bottom/2","doc":"*---*      *---*\n    -|---|- ->  |   |\n     *---*     -*---*-","ref":"RectLayout.html#threshold_bottom/2-visual"},{"type":"function","title":"Examples - RectLayout.threshold_bottom/2","doc":"iex> threshold_bottom(rect(2, 2), 5)\n    %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2}\n\n    iex> threshold_bottom(rect(2, 2, 0, 5), 4)\n    %RectLayout.Rect{x: 0, y: 2, width: 2, height: 2}","ref":"RectLayout.html#threshold_bottom/2-examples"},{"type":"function","title":"RectLayout.threshold_left/2","doc":"Push item to the right of a given line. If the line is before it, don't do anything","ref":"RectLayout.html#threshold_left/2"},{"type":"function","title":"Visual - RectLayout.threshold_left/2","doc":"*|--*    |---*\n    ||  | -> |   |\n    *|--*    |---*","ref":"RectLayout.html#threshold_left/2-visual"},{"type":"function","title":"Examples - RectLayout.threshold_left/2","doc":"iex> threshold_left(rect(2, 2), 1)\n    %RectLayout.Rect{x: 1, y: 0, width: 2, height: 2}\n\n    iex> threshold_left(rect(2, 2, 5), 1)\n    %RectLayout.Rect{x: 5, y: 0, width: 2, height: 2}","ref":"RectLayout.html#threshold_left/2-examples"},{"type":"function","title":"RectLayout.threshold_right/2","doc":"Push item to the left of a given line. If the line is before it, don't do anything","ref":"RectLayout.html#threshold_right/2"},{"type":"function","title":"Visual - RectLayout.threshold_right/2","doc":"|         |\n    *--|*    *---*\n    |  || -> |   |\n    *--|*    *---*\n       |         |","ref":"RectLayout.html#threshold_right/2-visual"},{"type":"function","title":"Examples - RectLayout.threshold_right/2","doc":"iex> threshold_right(rect(2, 2), 4)\n    %RectLayout.Rect{x: 0, y: 0, width: 2, height: 2}\n\n    iex> threshold_right(rect(2, 2, 5), 4)\n    %RectLayout.Rect{x: 2, y: 0, width: 2, height: 2}","ref":"RectLayout.html#threshold_right/2-examples"},{"type":"function","title":"RectLayout.threshold_top/2","doc":"Push item to the bottom of a given line. If the line is before it, don't do anything","ref":"RectLayout.html#threshold_top/2"},{"type":"function","title":"Visual - RectLayout.threshold_top/2","doc":"*---*     -*---*-\n    -|---|- ->  |   |\n     *---*      *---*","ref":"RectLayout.html#threshold_top/2-visual"},{"type":"function","title":"Examples - RectLayout.threshold_top/2","doc":"iex> threshold_top(rect(2, 2), 2)\n    %RectLayout.Rect{x: 0, y: 2, width: 2, height: 2}\n\n    iex> threshold_top(rect(2, 2, 0, 5), 2)\n    %RectLayout.Rect{x: 0, y: 5, width: 2, height: 2}","ref":"RectLayout.html#threshold_top/2-examples"},{"type":"function","title":"RectLayout.top/1","doc":"Get the topmost y of a list of items","ref":"RectLayout.html#top/1"},{"type":"function","title":"Visual - RectLayout.top/1","doc":"-*---*-----\n   |   |\n   *---*\n         *---*\n         |   |\n         *---*","ref":"RectLayout.html#top/1-visual"},{"type":"function","title":"Examples - RectLayout.top/1","doc":"iex> top([rect(2, 2), rect(2, 2, 2, 2)])\n  0","ref":"RectLayout.html#top/1-examples"},{"type":"function","title":"RectLayout.width/1","doc":"Get the width attribute of the item. Shortcut for `RectLayout.Object.width/1`","ref":"RectLayout.html#width/1"},{"type":"function","title":"RectLayout.width/2","doc":"Set the width attribute of the item. Shortcut for `RectLayout.Object.width/2`","ref":"RectLayout.html#width/2"},{"type":"function","title":"RectLayout.x/1","doc":"Get the x attribute of the item. Shortcut for `RectLayout.Object.x/1`","ref":"RectLayout.html#x/1"},{"type":"function","title":"RectLayout.x/2","doc":"Set the x attribute of the item. Shortcut for `RectLayout.Object.x/2`","ref":"RectLayout.html#x/2"},{"type":"function","title":"RectLayout.y/1","doc":"Get the y attribute of the item. Shortcut for `RectLayout.Object.y/1`","ref":"RectLayout.html#y/1"},{"type":"function","title":"RectLayout.y/2","doc":"Set the y attribute of the item. Shortcut for `RectLayout.Object.y/2`","ref":"RectLayout.html#y/2"},{"type":"type","title":"RectLayout.flow_horizontal_option/0","doc":"","ref":"RectLayout.html#t:flow_horizontal_option/0"},{"type":"type","title":"RectLayout.flow_vertical_option/0","doc":"","ref":"RectLayout.html#t:flow_vertical_option/0"},{"type":"type","title":"RectLayout.spread_horizontal_option/0","doc":"","ref":"RectLayout.html#t:spread_horizontal_option/0"},{"type":"type","title":"RectLayout.spread_vertical_option/0","doc":"","ref":"RectLayout.html#t:spread_vertical_option/0"},{"type":"module","title":"RectLayout.Group","doc":"Represent a group of graphical object, moves and scales them together proportionally\n\nAny change to its `x` and `y` would change all of its children with the same amount\nAny change in `width` and `height` would be propagated to its children proportionally\n\nShould not be created directly but by using the `RectLayout.group/1` constructor\n\nIf the children are modified externally should run the `RectLayout.group_children/2` to update them and the bounding rectangle\n\nImplements `RectLayout.Object` protocol so it can be used in the layout calculations","ref":"RectLayout.Group.html"},{"type":"type","title":"RectLayout.Group.t/0","doc":"","ref":"RectLayout.Group.html#t:t/0"},{"type":"protocol","title":"RectLayout.Object","doc":"A common attribute access protocol that graphical object implement\n  Allows them to be used inside the layout calculations\n  You can use your own custom objects as well, as long as they implement the same protocol","ref":"RectLayout.Object.html"},{"type":"function","title":"RectLayout.Object.height/1","doc":"","ref":"RectLayout.Object.html#height/1"},{"type":"function","title":"RectLayout.Object.height/2","doc":"","ref":"RectLayout.Object.html#height/2"},{"type":"function","title":"RectLayout.Object.width/1","doc":"","ref":"RectLayout.Object.html#width/1"},{"type":"function","title":"RectLayout.Object.width/2","doc":"","ref":"RectLayout.Object.html#width/2"},{"type":"function","title":"RectLayout.Object.x/1","doc":"","ref":"RectLayout.Object.html#x/1"},{"type":"function","title":"RectLayout.Object.x/2","doc":"","ref":"RectLayout.Object.html#x/2"},{"type":"function","title":"RectLayout.Object.y/1","doc":"","ref":"RectLayout.Object.html#y/1"},{"type":"function","title":"RectLayout.Object.y/2","doc":"","ref":"RectLayout.Object.html#y/2"},{"type":"type","title":"RectLayout.Object.t/0","doc":"All the types that implement this protocol.","ref":"RectLayout.Object.html#t:t/0"},{"type":"module","title":"RectLayout.Rect","doc":"Represent a rectangle. Used as the backbone of all the graphics calculations\nYou should probably not use this directly but use `%RectLayout.Sprite{}` structs as they can track which external (svg) object you are manipulating\n\nShould not be created directly but by using the `RectLayout.rect/4` constructor\n\nImplements `RectLayout.Object` protocol so it can be used in the layout calculations","ref":"RectLayout.Rect.html"},{"type":"type","title":"RectLayout.Rect.t/0","doc":"","ref":"RectLayout.Rect.html#t:t/0"},{"type":"module","title":"RectLayout.Sprite","doc":"Represent a graphical object and tracks its position and size using `%RectLayout.Rect{}` struct\n\nShould not be created directly but by using the `RectLayout.sprite/2` constructor\n\nImplements `RectLayout.Object` protocol so it can be used in the layout calculations","ref":"RectLayout.Sprite.html"},{"type":"type","title":"RectLayout.Sprite.t/0","doc":"","ref":"RectLayout.Sprite.html#t:t/0"},{"type":"extras","title":"RectLayout","doc":"# RectLayout\n\n[![Hex.pm](https://img.shields.io/hexpm/v/rect_layout.svg)](https://hexdocs.pm/rect_layout)\n[![github deploy](https://github.com/ivank/rect_layout/actions/workflows/deploy.yml/badge.svg)](https://github.com/ivank/rect_layout)\n[![codecov](https://codecov.io/gh/ivank/rect_layout/graph/badge.svg?token=T7UZUFT8VR)](https://codecov.io/gh/ivank/rect_layout)\n\nCreate and manipulate rectangular objects and groups of objects.\nThis is meant to allow generating dynamic svgs easier as it allows you to calculate positions of various svg elements with relation to each other.\n\nDocumentation: [https://hexdocs.pm/rect_layout](https://hexdocs.pm/rect_layout)","ref":"readme.html"},{"type":"extras","title":"Example - RectLayout","doc":"Arrange 6 images in 2 rows 3 columns, where images are constrained to height 100 and spread horizontally on each row in 500 pixels and aligned to their bottom.\n\n```elixir\niex> images = [\n...>  %{width: 25, height: 100, id: 1, src: \"http://example.com/img1.svg\"},\n...>  %{width: 16, height: 10, id: 2, src: \"http://example.com/img2.svg\"},\n...>  %{width: 16, height: 32, id: 3, src: \"http://example.com/img3.svg\"},\n...>  %{width: 88, height: 44, id: 4, src: \"http://example.com/img4.svg\"},\n...>  %{width: 30, height: 231, id: 5, src: \"http://example.com/img5.svg\"},\n...>  %{width: 332, height: 123, id: 6, src: \"http://example.com/img6.svg\"},\n...>]\niex> rows = images\n...>  |> Enum.map(&sprite(rect(&1.width, &1.height), &1))\n...>  |> Enum.chunk_every(3)\n...>  |> Enum.map(fn chunk ->\n...>    group(chunk |> constrain_width(100) |> spread_horizontal(500, gap: 2) |> align_bottom(100))\n...>  end)\n...>  |> flow_vertical(gap: 10)\niex> for row <- rows do\n...>   for s <- group_children(row) do\n...>     \" \"\n...>   end\n...> end\n[\n  [\n    \" \",\n    \" \",\n    \" \",\n  ],\n  [\n    \" \",\n    \" \",\n    \" \",\n  ]\n]\n```","ref":"readme.html#example"},{"type":"extras","title":"Installation - RectLayout","doc":"The package can be installed by adding `rect_layout` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:rect_layout, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE - RectLayout","doc":"See [LICENSE.md](/LICENSE.md)","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 Ivan Kerin\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}